import { 
  select, 
  csv, 
  scaleLinear, 
  max,
  scalePoint,
  axisLeft,
  axisBottom,
  format,
  extent
} from 'd3';

const svg = select('svg');
const width = svg.attr('width');
const height = svg.attr('height');

// Read in CSV
// ++++++++++++++++++++++++++++++++++
csv('https://vizhub.com/curran/datasets/auto-mpg.csv').then(data => {
  data.forEach(d => {
    d.mpg = +d.mpg
  	d.cylinders = +d.cylinders
  	d.displacement = +d.displacement
  	d.horsepower = +d.horsepower
  	d.weight = +d.weight
  	d.acceleration = +d.acceleration
  	d.year = +d.year
  });
  console.log(data);
  render(data);
});



// Render Graph
// ++++++++++++++++++++++++++++++++++
const render = data => {
  
  // Controlling Variables
  // ++++++++++++++++++++++++++++++++++
  const xValue = d => d.mpg;
  const yValue = d => d.weight;
  const xAxisLabel = 'mpg';
  const yAxisLabel = 'weight';
  const title = 'project';
  const radius = 5;
  const margin = {top:100,right:40,bottom:100,left:200}
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  // Master Group
  // ++++++++++++++++++++++++++++++++++
  const barGroup = svg.append('g')
  	.attr('transform',`translate(${margin.left},${margin.top})`)
  ;
  
  // Title
  // ++++++++++++++++++++++++++++++++++
  barGroup.append('text')
  	.attr('class','title')
  	.attr('y',-10)
  	.text(title)
  ;
  
  // X Axis
  // ++++++++++++++++++++++++++++++++++
  const xScale = scaleLinear()
  	.domain(extent(data,xValue))
  	.range([0, innerWidth])
  	.nice() // Ensures that the scale domain ends on a tick
  ;
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(20)
	;
  
  const xAxisGroup = barGroup.append('g')
    .call(xAxis)
  	.attr('transform', `translate(0,${innerHeight})`)
  ;
  
  // Remove ticks
	xAxisGroup.select('.domain ')
    .remove()
  ;
  
  xAxisGroup
  	.append('text')
    .attr('class', 'axis-label')
 	 	.attr('y',75)
  	.attr('x',innerWidth/2)
  	.attr('fill','black')
  	.text(xAxisLabel)
  ;
  
  // Y Axis
  // ++++++++++++++++++++++++++++++++++
  // Input data, output Y values to scale
  const yScale = scaleLinear()
  	.domain(extent(data,yValue))
  	.range([0, innerHeight])
  	.nice()
  ;
  
  // Tick Size
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(20)
  ;
  
  // Call
  const yAxisGroup = barGroup.append('g')
    .call(yAxis)
  ;
  
  // Remove Ticks
	yAxisGroup.selectAll('.domain')
    .remove()
  ;
  
  // Add Label
  yAxisGroup
  	.append('text')
      .text(yAxisLabel)
    	.attr('class','axis-label')
  		.attr('text-anchor','middle')
      .attr('y',-120)
      .attr('x',-innerHeight/2)
      .attr('fill','black')
  		.attr('transform',`rotate(-90)`)
      
  ;
  
  // Render Graph Objects
  // ++++++++++++++++++++++++++++++++++
  barGroup.selectAll().data(data)
  	.enter().append('circle')
  		.attr('r', radius)
    	.attr('cx', d => xScale(xValue(d)))
    	.attr('cy', d => yScale(yValue(d)))	
  ;
}




